#ifndef EEPROM24XX_H
#define EEPROM24XX_H

#include <inttypes.h>
#include <stdio.h>
#include <stdlib.h>

#include <avr/io.h>
#include <util/twi.h>		/* Note [1] */

#define DEBUG 1

/*
 * Note [3]
 * TWI address for 24Cxx EEPROM:
 *
 * 1 0 1 0 E2 E1 E0 R/~W	24C01/24C02
 * 1 0 1 0 E2 E1 A8 R/~W	24C04
 * 1 0 1 0 E2 A9 A8 R/~W	24C08
 * 1 0 1 0 A10 A9 A8 R/~W	24C16
 
 * 1 0 1 0 0 A1 A0 R/~W     24C512
 */
// #define TWI_SLA_24CXX	0xa0	/* E2 E1 E0 = 0 0 0 */
#define TWI_SLA_24CXX	0xa0	    /* E2 E1 E0 = 0 0 0 */

/*
 * Maximal number of iterations to wait for a device to respond for a
 * selection.  Should be large enough to allow for a pending write to
 * complete, but low enough to properly abort an infinite loop in case
 * a slave is broken or not present at all.  With 100 kHz TWI clock,
 * transfering the start condition and SLA+R/W packet takes about 10
 * s.  The longest write period is supposed to not exceed ~ 10 ms.
 * Thus, normal operation should not require more than 100 iterations
 * to get the device to respond to a selection.
 */
#define MAX_ITER	200

/*
 * Number of bytes that can be written in a row, see comments for
 * ee24xx_write_page() below.  Some vendor's devices would accept 16,
 * but 8 seems to be the lowest common denominator.
 *
 * Note that the page size must be a power of two, this simplifies the
 * page boundary calculations below.
 */
#define PAGE_SIZE 8

void init_twi(void);
int ee24xx_read_bytes(uint16_t eeaddr, int len, uint8_t *buf);
int ee24xx_write_page(uint16_t eeaddr, int len, uint8_t *buf);
int ee24xx_write_bytes(uint16_t eeaddr, int len, uint8_t *buf);
int uart_putchar(char c, FILE *unused) ;
void test_eeprom(void);
void error(void);


#endif
