/*! \file nmea.h \brief NMEA protocol function library. */
//*****************************************************************************
//
// File Name	: 'nmea.h'
// Title		: NMEA protocol function library
// Author		: Pascal Stang - Copyright (C) 2002
// Created		: 2002.08.27
// Revised		: 2002.08.27
// Version		: 0.1
// Target MCU	: Atmel AVR Series
// Editor Tabs	: 4
//
// NOTE: This code is currently below version 1.0, and therefore is considered
// to be lacking in some functionality or documentation, or may not be fully
// tested.  Nonetheless, you can expect most functions to work.
//
///	\ingroup driver_hw
/// \defgroup nmea NMEA Packet Interface for GPS Receivers (nmea.c)
/// \code #include "nmea.h" \endcode
/// \par Overview
///		This library parses and decodes the standard NMEA data stream from a
/// GPS and stores the position, velocity, and time solutions in the gps.c
/// library.
//
// This code is distributed under the GNU Public License
//		which can be found at http://www.gnu.org/licenses/gpl.txt
//
//*****************************************************************************

#ifndef NMEA_H
#define NMEA_H

#include "global.h"
#include "buffer.h"
#include "main.h"

// constants/macros/typdefs
#define NMEA_BUFFERSIZE		80

#define MAX             20

// Message Codes
#define NMEA_NODATA		0	// No data. Packet not available, bad, or not decoded
#define NMEA_GPGGA		1	// Global Positioning System Fix Data
#define NMEA_GPVTG		2	// Course over ground and ground speed
#define NMEA_GPGLL		3	// Geographic position - latitude/longitude
#define NMEA_GPGSV		4	// GPS satellites in view
#define NMEA_GPGSA		5	// GPS DOP and active satellites
#define NMEA_GPRMC		6	// Recommended minimum specific GPS data
#define NMEA_UNKNOWN	0xFF// Packet received but not known

#define PC_TREQ         7   // Anfrage zum bertragen der Anzahl der gespeicherten Datenstze
#define PC_TSET         8   // Anfrage einen Datensatz n zu bertragen
#define PC_WREQ         9   // Anfrage zum bertragen der Anzahl der gespeicherten Datenstze
#define PC_WSET         10   // Anfrage einen Datensatz n zu bertragen
#define PC_CLEAR        11   // Anfrage den Speicherindex auf 0 zurckzusetzen

// Functions
void nmeaInit(void);
uint8_t* nmeaGetPacketBuffer(void);
uint8_t nmeaProcess(cBuffer* rxBuffer);
void nmeaProcessGPGGA(uint8_t* packet);
void nmeaProcessGPRMC(uint8_t* packet);
void nmeaProcessGPGSA(uint8_t* packet);

void pcTransTREQ(void);
void pcTransWREQ(void);
void pcTransTSET(uint8_t* packet);
void pcTransWSET(uint8_t* packet);
void pcTransCLEAR(void);

struct GpsInfoType {
    char utc_time[11];
    char utc_date[8];
    char latitude[10];          // Breitengrad
    char latitude_ns[2];        // Breitengrad Nord/Sd
    char longitude[11];         // Lngengrad
    char longitude_ew[2];       // Lngengrad Ost/west
    char altitude[6];           // Hhe in m
    char fix[2];                // Art der Positionsbestimmung
};
#endif
