#include "main.h"
#include "uart.h"
#include "global.h"

void uinit(u08 baudrate) {
    u16 bauddivider = 0;
    switch (baudrate) {
        case B_4800:
            bauddivider	= (u16)(1.0 * XTAL / 4800 / 16 - 0.5);
            break;            
        case B_9600:
            bauddivider	= (u16)(1.0 * XTAL / 9600 / 16 - 0.5);
            break;
        case B_19200:
            bauddivider	= (u16)(1.0 * XTAL / 19200 / 16 - 0.5);
            break;            
        case B_38400:
            bauddivider	= (u16)(1.0 * XTAL / 38400 / 16 - 0.5);
            break;
        case B_57600:
            bauddivider	= (u16)(1.0 * XTAL / 57600 / 16 - 0.5);
            break;
        case B_115200:
            bauddivider	= (u16)(1.0 * XTAL / 115200 / 16 - 0.5);
            break;
    };   
    UBRRL = (u08) bauddivider;		                        // set baud rate
    UBRRH = bauddivider >> 8;
    UCSRA = 0;				                                // no U2X, MPCM
    UCSRC = 1 << URSEL ^ 1 << UCSZ1 ^ 1 << UCSZ0;	        // 8 Bit
    UCSRB = 1 << RXEN ^ 1 << TXEN;		                    // enable RX, TX
}

void uputchar( u08 c ) {
    while( (UCSRA & 1 << UDRE) == 0 );
    UDR = c;
}


void uputs( u08 *s ) {
    while( *s )
        uputchar( *s++ );
}

u08 uread( void ) {
    while (!(UCSRA & (1 << RXC)));  // warten bis Zeichen verfuegbar
        return UDR;                    // Zeichen aus UDR an Aufrufer zurueckgeben
}

